@@ -466,7 +466,13 @@ impl Options {
                 swc_plugin_runner::cache::init_plugin_module_cache_once(&experimental.cache_root);
             }
 
-            crate::plugin::plugins(plugin_resolver, experimental, plugin_context)
+            let comments = comments.cloned();
+            crate::plugin::plugins(
+                Some(plugin_resolver),
+                comments,
+                experimental,
+                plugin_context,
+            )
         };
 
         // Native runtime plugin target, based on assumption we have
@@ -486,7 +492,9 @@ impl Options {
                 env_name: self.env_name.to_owned(),
             };
 
-            crate::plugin::plugins(experimental, plugin_context)
+            swc_plugin_runner::cache::init_plugin_module_cache_once();
+            let comments = comments.cloned();
+            crate::plugin::plugins(None, comments, experimental, plugin_context)
         };
 
         #[cfg(not(feature = "plugin"))]
